@@ -13,7 +13,7 @@ forecast.varest <- function(object, h=10, level=c(80,95), fan=FALSE, ...)
 	out$mean <- out$lower <- out$upper <- vector("list",object$K)
 	for(i in 1:(length(level)))
 	{
-		pr <- predict(object, n.ahead=h, ci=level[i]/100)
+		pr <- predict(object, n.ahead=h, ci=level[i]/100, ...)
 		for(j in 1:object$K)
 		{
 			if(i==1)
@@ -64,4 +64,4 @@ plot.mforecast <- function(x, main=paste("Forecasts from",x$method),xlab="time",
 	axis(1)
 	mtext(xlab,outer=TRUE,side=1,line=3)
 	title(main=main,outer=TRUE)
-}
\ No newline at end of file
+}
